/*	put.c
	This is a set of formatting routines for use by dcmds.
	Copyright  1988 Apple Computer, Inc.  All rights reserved.

	Modification history:
		29Nov88 sad		revised for new dcmd names.
		 5Oct88 sad		written from file.c
 */

#include <Types.h>
#include <Memory.h>

#include "dcmd.h"

static Str255 line;
static int linepos = 0;


void PutLine()
{
	BlockMove(line,line+1,linepos);
	line[0] = linepos;
	dcmdDrawLine(line);
	linepos = 0;
} // PutLine


void PutChar(char c)
{
	line[linepos++] = c;
} // PutChar


void PutSpace()
{
	PutChar(' ');
} // PutSpace


void PutSpacesTo(int pos)
{
	while (linepos < pos) PutSpace();
} // PutSpacesTo


void PutBytesTruncTo(const char* s, int len, int pos)
{
	if (pos > linepos)
		{
		if (len <= pos - linepos)
			{
			BlockMove(s,line+linepos,len);
			linepos += len;
			while (linepos < pos) PutSpace();
			}
		else
			{
			BlockMove(s,line+linepos,pos-linepos-1);
			linepos = pos - 1;
			PutChar('');
			}
		line[linepos] = '\0';
		}
} // PutBytesTruncTo


void PutBytesTo(const char* s, int len, int pos)
{
	BlockMove(s,line+linepos,len);
	linepos += len;
	while (linepos < pos) PutSpace();
	line[linepos] = '\0';
} // PutBytesTo


void PutCStrTo(const char* s, int pos)
{
	int slen = strlen(s);
	PutBytesTo(s,slen,pos);
} // PutCStrTo


void PutCStrTruncTo(const char* s, int pos)
{
	int slen = strlen(s);
	PutBytesTruncTo(s,slen,pos);
} // PutCStrTo


void PutCStr(const char* s)
{
	int slen = strlen(s);
	PutBytesTo(s,slen,0);
} // PutCStr


void PutPStrTruncTo(const char* s, int pos)
{
	int slen = *(unsigned char *)s;
	PutBytesTruncTo(s+1,slen,pos);
} // PutPStrTo


void PutPStrTo(const char* s, int pos)
{
	int slen = *(unsigned char *)s;
	PutBytesTo(s+1,slen,pos);
} // PutPStrTo


void PutPStr(const char* s)
{
	int slen = *(unsigned char *)s;
	PutBytesTo(s+1,slen,0);
} // PutPStr


void PutUHexZTo(unsigned long i, int ndig, int pos)
{
unsigned long dig = i % 0x10;
unsigned long rest = i / 0x10;
	if (rest != 0) PutUHexZTo(rest,ndig - 1,pos - 1);
	else
		{
		pos -= 1;		// one for this digit
		if (ndig > 0) pos -= ndig - 1;		// the leading zeros
		while (linepos < pos) PutSpace();
		while (--ndig > 0) PutChar('0');
		}
	if (dig < 10) PutChar('0' + dig);
	else PutChar('a' + (dig - 10));
} // PutUHexZTo


void PutUHexZ(unsigned long i, int nz)
{
	PutUHexZTo(i,nz,0);
} // PutUHexZ


void PutUHexWord(unsigned long i)
{
	PutUHexZTo((unsigned short)i,4,0);
} // PutUHexZ


void PutUDecTo(unsigned long i, int pos)
{
unsigned long dig = i % 10;
unsigned long rest = i / 10;
	if (rest != 0) PutUDecTo(rest,pos - 1);
	else
		{
		pos -= 2;	// one for the '#' and one for this digit
		while (linepos < pos) PutSpace();
		PutChar('#');
		}
	PutChar('0' + dig);
} // PutUDecTo


void PutUDec(unsigned long i)
{
	PutUDecTo(i,0);
} // PutUDec


void PutOSType(unsigned long typ)
{
	PutChar((typ>>24) & 0xff);
	PutChar((typ>>16) & 0xff);
	PutChar((typ>>8) & 0xff);
	PutChar(typ & 0xff);
} // PutOSType
